@@ -157,6 +157,6 @@ class PyPugJSExtension(Extension):
         if hasattr(loader, 'searchpath') and len(loader.searchpath):
             self.options["basedir"] = loader.searchpath[0]
 
-        if not name or (name and not os.path.splitext(name)[1] in self.file_extensions):
+        if not name or (name and os.path.splitext(name)[1] not in self.file_extensions):
             return source
         return process(source, filename=name, compiler=Compiler, **self.options)
